#region Copyright Syncfusion Inc. 2001 - 2014
// Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Reflection;
using Syncfusion.Windows.Chart;
using Syncfusion.Windows.Shared;
using Syncfusion.Windows.SampleLayout;

namespace ZoomingAndScrolling
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : SampleLayoutWindow
    {
        #region Constructor
        /// <summary>
        /// Constructor for Window1
        /// </summary>
        public Window1()
        {
            InitializeComponent();
            canvas = new Canvas();
            rectangle = new Rectangle();
            rectangle.Visibility = Visibility.Collapsed;
            rectangle.Fill = new SolidColorBrush(Color.FromArgb(0xC0, 0xFF, 0xFF, 0xFF));
            rectangle.Stroke = Brushes.Black;
            rectangle.Stretch = Stretch.Fill;
            canvas.Children.Add(rectangle);
            ChartAreaGrid.Children.Add(canvas);
        }
        Rectangle rectangle;
        Canvas canvas;
        Point m_startZoomBarPoint = new Point();
        Point m_endZoomBarPoint = new Point();
        #endregion             

        private void area_MouseMove(object sender, MouseEventArgs e)
        {
            ChartArea area = sender as ChartArea;

            if (e.RightButton == MouseButtonState.Pressed)
            {

                Point mPt = e.GetPosition(canvas);
                Rect canvasRect = new Rect(canvas.RenderSize);

                double Xaxisvalue = area.PointToValue(area.SecondaryAxis, e.GetPosition(sender as ChartArea));
                double Yaxisvalue = area.PointToValue(area.PrimaryAxis, e.GetPosition(sender as ChartArea));

                mPt.X = ChartMath.MinMax(mPt.X, 0, canvas.ActualWidth);
                mPt.Y = ChartMath.MinMax(mPt.Y, 0, canvas.ActualHeight);
                m_endZoomBarPoint = mPt;

                Rect zoomRect = new Rect(m_startZoomBarPoint, m_endZoomBarPoint);
                if (area.SecondaryAxis.VisibleRange.Start <= (Xaxisvalue) && area.SecondaryAxis.VisibleRange.End >= (Xaxisvalue))
                {
                    Canvas.SetTop(rectangle, zoomRect.Y);
                    rectangle.Height = zoomRect.Height;
                }
                if (area.PrimaryAxis.VisibleRange.End >= Yaxisvalue && area.PrimaryAxis.VisibleRange.Start <= Yaxisvalue)
                {
                    Canvas.SetLeft(rectangle, zoomRect.X);
                    rectangle.Width = zoomRect.Width;
                }
            }
        }

          
        private void area_MouseDown(object sender, MouseButtonEventArgs e)
        {
            ChartArea area = sender as ChartArea;
            if (e.ChangedButton == MouseButton.Right)
            {
                Point mPt = e.GetPosition(canvas);

                mPt.X = ChartMath.MinMax(mPt.X, 0, canvas.ActualWidth);
                mPt.Y = ChartMath.MinMax(mPt.Y, 0, canvas.ActualHeight);


                 if ((area.Cursor != Cursors.Hand))
                {
                    area.CaptureMouse();
                    m_startZoomBarPoint = mPt;

                    Canvas.SetLeft(rectangle, m_startZoomBarPoint.X);
                    Canvas.SetTop(rectangle, m_startZoomBarPoint.Y);

                    rectangle.Width = 0;
                    rectangle.Height = 0;
                    rectangle.Visibility = Visibility.Visible;
                }
                else
                {
                    rectangle.Visibility = Visibility.Collapsed;
                }
            }
        }

        private void area_MouseUp(object sender, MouseButtonEventArgs e)
        {
            ChartArea m_chartArea = sender as ChartArea;
            rectangle.Visibility = Visibility.Collapsed;
            m_chartArea.ReleaseMouseCapture();

            Point zp1 = canvas.TranslatePoint(m_startZoomBarPoint, m_chartArea);
            Point zp2 = canvas.TranslatePoint(m_endZoomBarPoint, m_chartArea);
            Rect rect = new Rect(zp1, zp2);

            if (rect.Width > 0 && rect.Height > 0 && m_chartArea != null)
            {
                ChartAreaCommands.ZoomSector.Execute(rect, m_chartArea);
            }
        }
    }

    

}
